==> lhcsmapi-1.3.229.tar.gz: lhcsmapi-1.3.229/test/test_gui/test_FgcPmSearchModuleMediator.py <==
import unittest

from lhcsmapi.gui.pc.FgcPmSearchModuleMediator import get_circuit_names_or_types


class TestFgcPmSearchModuleMediator(unittest.TestCase):

    def test_get_circuit_names_rb(self):
        # arrange
        circuit_type = 'RB'

        # act
        circuit_names_act = get_circuit_names_or_types(circuit_type)

        # assert
        circuit_names_ref = ['RB.A12', 'RB.A23', 'RB.A34', 'RB.A45', 'RB.A56', 'RB.A67', 'RB.A78', 'RB.A81']

        circuit_names_act.sort()
        circuit_names_ref.sort()
        self.assertEquals(circuit_names_ref, circuit_names_act)

    def test_get_circuit_names_rq(self):
        # arrange
        circuit_type = 'RQ'

        # act
        circuit_names_act = get_circuit_names_or_types(circuit_type)

        # assert
        circuit_names_ref = ['RQ.A12', 'RQ.A23', 'RQ.A34', 'RQ.A45', 'RQ.A56', 'RQ.A67', 'RQ.A78', 'RQ.A81']

        circuit_names_act.sort()
        circuit_names_ref.sort()
        self.assertEquals(circuit_names_ref, circuit_names_act)

    def test_get_circuit_names_600A(self):
        # arrange
        circuit_type = '600A'

        # act
        circuit_names_act = get_circuit_names_or_types(circuit_type)

        # assert
        circuit_names_ref = ['RCS', 'ROD', 'ROF', 'RQ6', 'RQS', 'RQSX3', 'RQT12', 'RQT13', 'RQTD', 'RQTF', 'RQTL10',
                             'RQTL11', 'RQTL7', 'RQTL8', 'RQTL9', 'RSD1', 'RSD2', 'RSF1', 'RSF2', 'RSS', 'RU']
        circuit_names_act.sort()
        circuit_names_ref.sort()
        self.assertEquals(circuit_names_ref, circuit_names_act)

    def test_get_circuit_names_600A_RCBXHV(self):
        # arrange
        circuit_type = '600A_RCBXHV'

        # act
        circuit_names_act = get_circuit_names_or_types(circuit_type)

        # assert
        circuit_names_ref = ['RCBX1.L1', 'RCBX1.L2', 'RCBX1.L5', 'RCBX1.L8', 'RCBX1.R1', 'RCBX1.R2', 'RCBX1.R5',
                              'RCBX1.R8', 'RCBX2.L1', 'RCBX2.L2', 'RCBX2.L5', 'RCBX2.L8', 'RCBX2.R1', 'RCBX2.R2',
                              'RCBX2.R5', 'RCBX2.R8', 'RCBX3.L1', 'RCBX3.L2', 'RCBX3.L5', 'RCBX3.L8', 'RCBX3.R1',
                              'RCBX3.R2', 'RCBX3.R5', 'RCBX3.R8']
        circuit_names_act.sort()
        circuit_names_ref.sort()
        self.assertEquals(circuit_names_ref, circuit_names_act)

    def test_get_circuit_names_600A_RCDO(self):
        # arrange
        circuit_type = '600A_RCDO'

        # act
        circuit_names_act = get_circuit_names_or_types(circuit_type)

        # assert
        circuit_names_ref = ['RC.A12B1', 'RC.A12B2', 'RC.A23B1', 'RC.A23B2', 'RC.A34B1', 'RC.A34B2', 'RC.A45B1',
                             'RC.A45B2', 'RC.A56B1', 'RC.A56B2', 'RC.A67B1', 'RC.A67B2', 'RC.A78B1', 'RC.A78B2',
                             'RC.A81B1', 'RC.A81B2']
        circuit_names_act.sort()
        circuit_names_ref.sort()
        self.assertEquals(circuit_names_ref, circuit_names_act)

==> lhcsmapi-1.4.58.tar.gz: lhcsmapi-1.4.58/test/test_gui/test_FgcPmSearchModuleMediator.py <==
import unittest

from lhcsmapi.gui.pc.FgcPmSearchModuleMediator import get_circuit_names_or_types


class TestFgcPmSearchModuleMediator(unittest.TestCase):

    def test_get_circuit_names_rb(self):
        # arrange
        circuit_type = 'RB'

        # act
        circuit_names_act = get_circuit_names_or_types(circuit_type)

        # assert
        circuit_names_ref = ['RB.A12', 'RB.A23', 'RB.A34', 'RB.A45', 'RB.A56', 'RB.A67', 'RB.A78', 'RB.A81']

        circuit_names_act.sort()
        circuit_names_ref.sort()
        self.assertEqual(circuit_names_ref, circuit_names_act)

    def test_get_circuit_names_rq(self):
        # arrange
        circuit_type = 'RQ'

        # act
        circuit_names_act = get_circuit_names_or_types(circuit_type)

        # assert
        circuit_names_ref = ['RQ.A12', 'RQ.A23', 'RQ.A34', 'RQ.A45', 'RQ.A56', 'RQ.A67', 'RQ.A78', 'RQ.A81']

        circuit_names_act.sort()
        circuit_names_ref.sort()
        self.assertEqual(circuit_names_ref, circuit_names_act)

    def test_get_circuit_names_600A(self):
        # arrange
        circuit_type = '600A'

        # act
        circuit_names_act = get_circuit_names_or_types(circuit_type)

        # assert
        circuit_names_ref = ['RCS', 'ROD', 'ROF', 'RQ6', 'RQS', 'RQSX3', 'RQT12', 'RQT13', 'RQTD', 'RQTF', 'RQTL10',
                             'RQTL11', 'RQTL7', 'RQTL8', 'RQTL9', 'RSD1', 'RSD2', 'RSF1', 'RSF2', 'RSS', 'RU']
        circuit_names_act.sort()
        circuit_names_ref.sort()
        self.assertEqual(circuit_names_ref, circuit_names_act)

    def test_get_circuit_names_600A_RCBXHV(self):
        # arrange
        circuit_type = '600A_RCBXHV'

        # act
        circuit_names_act = get_circuit_names_or_types(circuit_type)

        # assert
        circuit_names_ref = ['RCBX1.L1', 'RCBX1.L2', 'RCBX1.L5', 'RCBX1.L8', 'RCBX1.R1', 'RCBX1.R2', 'RCBX1.R5',
                              'RCBX1.R8', 'RCBX2.L1', 'RCBX2.L2', 'RCBX2.L5', 'RCBX2.L8', 'RCBX2.R1', 'RCBX2.R2',
                              'RCBX2.R5', 'RCBX2.R8', 'RCBX3.L1', 'RCBX3.L2', 'RCBX3.L5', 'RCBX3.L8', 'RCBX3.R1',
                              'RCBX3.R2', 'RCBX3.R5', 'RCBX3.R8']
        circuit_names_act.sort()
        circuit_names_ref.sort()
        self.assertEqual(circuit_names_ref, circuit_names_act)

    def test_get_circuit_names_600A_RCDO(self):
        # arrange
        circuit_type = '600A_RCDO'

        # act
        circuit_names_act = get_circuit_names_or_types(circuit_type)

        # assert
        circuit_names_ref = ['RC.A12B1', 'RC.A12B2', 'RC.A23B1', 'RC.A23B2', 'RC.A34B1', 'RC.A34B2', 'RC.A45B1',
                             'RC.A45B2', 'RC.A56B1', 'RC.A56B2', 'RC.A67B1', 'RC.A67B2', 'RC.A78B1', 'RC.A78B2',
                             'RC.A81B1', 'RC.A81B2']
        circuit_names_act.sort()
        circuit_names_ref.sort()
        self.assertEqual(circuit_names_ref, circuit_names_act)
